**** SVAR_JEP.DO

*** September 4, 2018
*** VAR example for Valerie Ramey "Ten Years after the Financial Crisis: What
***     Have We Learned from the Renaissance in Fiscal Research,"
***     Journal of Economic Perspectives

*** Uses logs, Gordon-Krenn (GK) transformation (i.e. variables are divided by potential)

***   Data: subset of the Ramey-Zubairy (2018 JPE) data set:  ramey_jep_dat.xlsx
********************************************************************************

#delimit;  /* Sets semi-colons as delimiters at end of commands */

drop _all;
clear all;

set more 1;
set matsize 800;

capture log close;
log using fiscalvar_results.log, replace;


*******************************************************************************;
** RAW DATA IMPORTATION AND DATA SETUP;
*******************************************************************************;

import excel ramey_jep_dat.xlsx, sheet("main") firstrow;

label var	ngov	"nominal government purchases"	;
label var	ngdp	"nominal GDP"	;
label var	pgdp	"GDP implicit price deflator"	;
label var	pop	"total population, including armed forces overseas"	;
label var	news	"PDV of expected changes in government spending due to military events"	;
label var	rgdp	"real GDP"	;
label var	nfedcurrreceipts_nipa	"nominal Federal current receipts, NIPA accrual basis"	;
label var	tbill	"3-month treasury bill rate, secondary market"	;
label var	rgdp_pott6	"real potential GDP, based on 6th degree polynomial fit from 1889:1 - 2015:4, ommiting Great Depression and WWII	"	;

* TELL STATA THAT THE DATA SET IS A TIME SERIES DATA SET;

gen qdate = q(1938q1) + _n-1;
tsset qdate, q;


* DEFLATE BASIC VARIABLES;

gen newsy = news/(L.rgdp_pott6*L.pgdp);
gen rgov = ngov/pgdp; 
gen rtax = nfedcurrreceipts_nipa/pgdp;

label var newsy "military spending news, normalized by nominal potential GDP";
label var rgov "real government spending, deflated by GDP deflator";
label var rtax "real federal tax revenue, deflated by GDP deflator";

* CALCULATE THE SAMPLE AVERAGE OF GDP/GOV FOR THE AD HOC CONVERSATION FACTOR;

gen yg = rgdp/rgov;
summ yg;

*LOG MEASURES OF VARIABLES;

gen lpgdp = ln(pgdp);
gen ly = ln(rgdp/pop);
gen lg = ln(rgov/pop);
gen lt = ln(rtax/pop);

label var lpgdp "log GDP deflator";
label var ly "log real GDP per capita";
label var lg "log real government spending per capita";
label var lt "log real federal tax revenue per capita";

gen infl = 400*D.lpgdp;

label var infl "inflation rate";

* GORDON-KRENN TRANSFORMED VARIABLES;

gen y_gk = rgdp/rgdp_pott6;
gen g_gk = rgov/rgdp_pott6;
gen tax_gk = rtax/rgdp_pott6;

label var y_gk "Real GDP normalized by potential GDP";
label var g_gk "Real government spending normalized by potential GDP";
label var tax_gk "Real federal tax revenue normalized by potential GDP";


*******************************************************************************;
** ESTIMATE THE STRUCTURAL VECTOR AUTOREGRESSIONS USING BLANCHARD-PEROTTI IDENTIFICATION;
*******************************************************************************;

drop if qdate<q(1939q1);


*Log specification;

var lg ly lt infl tbill, lags(1/4) ; /*Estimates the VAR using 4 lags. By ordering
   lg first, we are assuming that the forecast error in lg is the exogenous shock
   to lg, as in Blanchard and Perotti*/
   
irf create bpvar, step(20) set(bpvar, replace); /*Obtains the impulse responses*/

irf table oirf, impulse(lg) response(lg ly) noci; /*Prints the impulse responses
     of government spending and GDP to a government spending shock
	 in a table.  Copy and paste to Excel*/
	 
irf graph oirf, impulse(lg) response(lg ly) byopts(yrescale); /* Graphs the
     impulse responses*/



	 
*Gordon-Krenn specification;

var g_gk y_gk tax_gk infl tbill, lags(1/4) ; /*Estimates the VAR using 4 lags. By ordering
   lg first, we are assuming that the forecast error in lg is the exogenous shock
   to lg, as in Blanchard and Perotti*/
   
irf create bpvar, step(20) set(bpvar, replace); /*Obtains the impulse responses*/

irf table oirf, impulse(g_gk) response(g_gk y_gk) noci; /*Prints the impulse responses
     of government spending and GDP to a government spending shock
     in a table along with the 95 percent confidence bands.  Copy and paste to Excel*/

irf graph oirf, impulse(g_gk) response(g_gk y_gk) byopts(yrescale); /* Graphs the
     impulse responses*/

	 
/*	 
*******************************************************************************;
** ESTIMATE THE STRUCTURAL VECTOR AUTOREGRESSIONS USING RAMEY-ZUBAIRY MILITARY NEWS;
** These are additional estimates, not reported in the JEP article;
*******************************************************************************;

drop if qdate<q(1939q1);

*Log specification;

var newsy lg ly lt infl tbill, lags(1/4) ; /*Estimates the VAR using 4 lags. By ordering
   military news first, we are using shocks to that variable as the exogenous shock,
   as in Ramey (2011a) and Ramey-Zubairy (2018)*/
   
irf create bpvar, step(20) set(bpvar, replace); /*Obtains the impulse responses*/

irf table oirf, impulse(newsy) response(lg ly) noci; /*Prints the impulse responses
     of government spending and GDP to a government spending shock
	 in a table along with the 95 percent confidence bands.  Copy and paste to Excel*/

irf graph oirf, impulse(newsy) response(lg ly) byopts(yrescale); /* Graphs the
     impulse responses*/

	 
*Gordon-Krenn specification;

var newsy g_gk y_gk tax_gk infl tbill, lags(1/4) ; /*Estimates the VAR using 4 lags. By ordering
   lg first, we are assuming that the forecast error in lg is the exogenous shock
   to lg, as in Blanchard and Perotti*/
   
irf create newsvar, step(20) set(newsvar, replace); /*Obtains the impulse responses*/

irf table oirf, impulse(newsy) response(g_gk y_gk) noci; /*Prints the impulse responses
     of government spending and GDP to a government spending shock
	 in a table along with the 95 percent confidence bands.  Copy and paste to Excel*/

irf graph oirf, impulse(newsy) response(g_gk y_gk) byopts(yrescale); /* Graphs the
     impulse responses*/


capture log close;

 
